# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseExperimentListResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created_by': 'ResponseSimpleUser',
        'created_dt': 'datetime',
        'env_vars': 'OrmEnvVars',
        'estimated_end_dt': 'datetime',
        'histories': 'list[ResponseWorkloadHistoryInfo]',
        'id': 'int',
        'is_distributed': 'bool',
        'is_local': 'bool',
        'kernel_cluster': 'ResponseKernelCluster',
        'kernel_resource_spec': 'ResponseKernelResourceSpec',
        'last_alive': 'datetime',
        'message': 'str',
        'metrics_summary': 'OrmExperimentMetricsSummary',
        'name': 'str',
        'number': 'int',
        'organization': 'ResponseOrganization',
        'progress_percent': 'float',
        'project': 'ResponseProject',
        'show_plots': 'bool',
        'status': 'str',
        'status_last_updated': 'datetime',
        'status_reason': 'str',
        'sweep': 'ResponseSimpleSweep',
        'tags': 'list[ResponseTagResponse]',
        'updated_dt': 'datetime',
        'workload_status': 'str'
    }

    attribute_map = {
        'created_by': 'created_by',
        'created_dt': 'created_dt',
        'env_vars': 'env_vars',
        'estimated_end_dt': 'estimated_end_dt',
        'histories': 'histories',
        'id': 'id',
        'is_distributed': 'is_distributed',
        'is_local': 'is_local',
        'kernel_cluster': 'kernel_cluster',
        'kernel_resource_spec': 'kernel_resource_spec',
        'last_alive': 'last_alive',
        'message': 'message',
        'metrics_summary': 'metrics_summary',
        'name': 'name',
        'number': 'number',
        'organization': 'organization',
        'progress_percent': 'progress_percent',
        'project': 'project',
        'show_plots': 'show_plots',
        'status': 'status',
        'status_last_updated': 'status_last_updated',
        'status_reason': 'status_reason',
        'sweep': 'sweep',
        'tags': 'tags',
        'updated_dt': 'updated_dt',
        'workload_status': 'workload_status'
    }

    def __init__(self, created_by=None, created_dt=None, env_vars=None, estimated_end_dt=None, histories=None, id=None, is_distributed=None, is_local=None, kernel_cluster=None, kernel_resource_spec=None, last_alive=None, message=None, metrics_summary=None, name=None, number=None, organization=None, progress_percent=None, project=None, show_plots=None, status=None, status_last_updated=None, status_reason=None, sweep=None, tags=None, updated_dt=None, workload_status=None, local_vars_configuration=None):  # noqa: E501
        """ResponseExperimentListResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_by = None
        self._created_dt = None
        self._env_vars = None
        self._estimated_end_dt = None
        self._histories = None
        self._id = None
        self._is_distributed = None
        self._is_local = None
        self._kernel_cluster = None
        self._kernel_resource_spec = None
        self._last_alive = None
        self._message = None
        self._metrics_summary = None
        self._name = None
        self._number = None
        self._organization = None
        self._progress_percent = None
        self._project = None
        self._show_plots = None
        self._status = None
        self._status_last_updated = None
        self._status_reason = None
        self._sweep = None
        self._tags = None
        self._updated_dt = None
        self._workload_status = None
        self.discriminator = None

        self.created_by = created_by
        self.created_dt = created_dt
        if env_vars is not None:
            self.env_vars = env_vars
        self.estimated_end_dt = estimated_end_dt
        self.histories = histories
        self.id = id
        self.is_distributed = is_distributed
        self.is_local = is_local
        if kernel_cluster is not None:
            self.kernel_cluster = kernel_cluster
        if kernel_resource_spec is not None:
            self.kernel_resource_spec = kernel_resource_spec
        if last_alive is not None:
            self.last_alive = last_alive
        self.message = message
        if metrics_summary is not None:
            self.metrics_summary = metrics_summary
        self.name = name
        self.number = number
        self.organization = organization
        self.progress_percent = progress_percent
        self.project = project
        self.show_plots = show_plots
        self.status = status
        self.status_last_updated = status_last_updated
        self.status_reason = status_reason
        if sweep is not None:
            self.sweep = sweep
        self.tags = tags
        self.updated_dt = updated_dt
        if workload_status is not None:
            self.workload_status = workload_status

    @property
    def created_by(self):
        """Gets the created_by of this ResponseExperimentListResponse.  # noqa: E501


        :return: The created_by of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: ResponseSimpleUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ResponseExperimentListResponse.


        :param created_by: The created_by of this ResponseExperimentListResponse.  # noqa: E501
        :type created_by: ResponseSimpleUser
        """
        if self.local_vars_configuration.client_side_validation and created_by is None:  # noqa: E501
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def created_dt(self):
        """Gets the created_dt of this ResponseExperimentListResponse.  # noqa: E501


        :return: The created_dt of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this ResponseExperimentListResponse.


        :param created_dt: The created_dt of this ResponseExperimentListResponse.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def env_vars(self):
        """Gets the env_vars of this ResponseExperimentListResponse.  # noqa: E501


        :return: The env_vars of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: OrmEnvVars
        """
        return self._env_vars

    @env_vars.setter
    def env_vars(self, env_vars):
        """Sets the env_vars of this ResponseExperimentListResponse.


        :param env_vars: The env_vars of this ResponseExperimentListResponse.  # noqa: E501
        :type env_vars: OrmEnvVars
        """

        self._env_vars = env_vars

    @property
    def estimated_end_dt(self):
        """Gets the estimated_end_dt of this ResponseExperimentListResponse.  # noqa: E501


        :return: The estimated_end_dt of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._estimated_end_dt

    @estimated_end_dt.setter
    def estimated_end_dt(self, estimated_end_dt):
        """Sets the estimated_end_dt of this ResponseExperimentListResponse.


        :param estimated_end_dt: The estimated_end_dt of this ResponseExperimentListResponse.  # noqa: E501
        :type estimated_end_dt: datetime
        """

        self._estimated_end_dt = estimated_end_dt

    @property
    def histories(self):
        """Gets the histories of this ResponseExperimentListResponse.  # noqa: E501


        :return: The histories of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: list[ResponseWorkloadHistoryInfo]
        """
        return self._histories

    @histories.setter
    def histories(self, histories):
        """Sets the histories of this ResponseExperimentListResponse.


        :param histories: The histories of this ResponseExperimentListResponse.  # noqa: E501
        :type histories: list[ResponseWorkloadHistoryInfo]
        """
        if self.local_vars_configuration.client_side_validation and histories is None:  # noqa: E501
            raise ValueError("Invalid value for `histories`, must not be `None`")  # noqa: E501

        self._histories = histories

    @property
    def id(self):
        """Gets the id of this ResponseExperimentListResponse.  # noqa: E501


        :return: The id of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ResponseExperimentListResponse.


        :param id: The id of this ResponseExperimentListResponse.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def is_distributed(self):
        """Gets the is_distributed of this ResponseExperimentListResponse.  # noqa: E501


        :return: The is_distributed of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_distributed

    @is_distributed.setter
    def is_distributed(self, is_distributed):
        """Sets the is_distributed of this ResponseExperimentListResponse.


        :param is_distributed: The is_distributed of this ResponseExperimentListResponse.  # noqa: E501
        :type is_distributed: bool
        """
        if self.local_vars_configuration.client_side_validation and is_distributed is None:  # noqa: E501
            raise ValueError("Invalid value for `is_distributed`, must not be `None`")  # noqa: E501

        self._is_distributed = is_distributed

    @property
    def is_local(self):
        """Gets the is_local of this ResponseExperimentListResponse.  # noqa: E501


        :return: The is_local of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_local

    @is_local.setter
    def is_local(self, is_local):
        """Sets the is_local of this ResponseExperimentListResponse.


        :param is_local: The is_local of this ResponseExperimentListResponse.  # noqa: E501
        :type is_local: bool
        """
        if self.local_vars_configuration.client_side_validation and is_local is None:  # noqa: E501
            raise ValueError("Invalid value for `is_local`, must not be `None`")  # noqa: E501

        self._is_local = is_local

    @property
    def kernel_cluster(self):
        """Gets the kernel_cluster of this ResponseExperimentListResponse.  # noqa: E501


        :return: The kernel_cluster of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: ResponseKernelCluster
        """
        return self._kernel_cluster

    @kernel_cluster.setter
    def kernel_cluster(self, kernel_cluster):
        """Sets the kernel_cluster of this ResponseExperimentListResponse.


        :param kernel_cluster: The kernel_cluster of this ResponseExperimentListResponse.  # noqa: E501
        :type kernel_cluster: ResponseKernelCluster
        """

        self._kernel_cluster = kernel_cluster

    @property
    def kernel_resource_spec(self):
        """Gets the kernel_resource_spec of this ResponseExperimentListResponse.  # noqa: E501


        :return: The kernel_resource_spec of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: ResponseKernelResourceSpec
        """
        return self._kernel_resource_spec

    @kernel_resource_spec.setter
    def kernel_resource_spec(self, kernel_resource_spec):
        """Sets the kernel_resource_spec of this ResponseExperimentListResponse.


        :param kernel_resource_spec: The kernel_resource_spec of this ResponseExperimentListResponse.  # noqa: E501
        :type kernel_resource_spec: ResponseKernelResourceSpec
        """

        self._kernel_resource_spec = kernel_resource_spec

    @property
    def last_alive(self):
        """Gets the last_alive of this ResponseExperimentListResponse.  # noqa: E501


        :return: The last_alive of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._last_alive

    @last_alive.setter
    def last_alive(self, last_alive):
        """Sets the last_alive of this ResponseExperimentListResponse.


        :param last_alive: The last_alive of this ResponseExperimentListResponse.  # noqa: E501
        :type last_alive: datetime
        """

        self._last_alive = last_alive

    @property
    def message(self):
        """Gets the message of this ResponseExperimentListResponse.  # noqa: E501


        :return: The message of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ResponseExperimentListResponse.


        :param message: The message of this ResponseExperimentListResponse.  # noqa: E501
        :type message: str
        """
        if self.local_vars_configuration.client_side_validation and message is None:  # noqa: E501
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def metrics_summary(self):
        """Gets the metrics_summary of this ResponseExperimentListResponse.  # noqa: E501


        :return: The metrics_summary of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: OrmExperimentMetricsSummary
        """
        return self._metrics_summary

    @metrics_summary.setter
    def metrics_summary(self, metrics_summary):
        """Sets the metrics_summary of this ResponseExperimentListResponse.


        :param metrics_summary: The metrics_summary of this ResponseExperimentListResponse.  # noqa: E501
        :type metrics_summary: OrmExperimentMetricsSummary
        """

        self._metrics_summary = metrics_summary

    @property
    def name(self):
        """Gets the name of this ResponseExperimentListResponse.  # noqa: E501


        :return: The name of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ResponseExperimentListResponse.


        :param name: The name of this ResponseExperimentListResponse.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def number(self):
        """Gets the number of this ResponseExperimentListResponse.  # noqa: E501


        :return: The number of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this ResponseExperimentListResponse.


        :param number: The number of this ResponseExperimentListResponse.  # noqa: E501
        :type number: int
        """
        if self.local_vars_configuration.client_side_validation and number is None:  # noqa: E501
            raise ValueError("Invalid value for `number`, must not be `None`")  # noqa: E501

        self._number = number

    @property
    def organization(self):
        """Gets the organization of this ResponseExperimentListResponse.  # noqa: E501


        :return: The organization of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: ResponseOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this ResponseExperimentListResponse.


        :param organization: The organization of this ResponseExperimentListResponse.  # noqa: E501
        :type organization: ResponseOrganization
        """
        if self.local_vars_configuration.client_side_validation and organization is None:  # noqa: E501
            raise ValueError("Invalid value for `organization`, must not be `None`")  # noqa: E501

        self._organization = organization

    @property
    def progress_percent(self):
        """Gets the progress_percent of this ResponseExperimentListResponse.  # noqa: E501


        :return: The progress_percent of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: float
        """
        return self._progress_percent

    @progress_percent.setter
    def progress_percent(self, progress_percent):
        """Sets the progress_percent of this ResponseExperimentListResponse.


        :param progress_percent: The progress_percent of this ResponseExperimentListResponse.  # noqa: E501
        :type progress_percent: float
        """

        self._progress_percent = progress_percent

    @property
    def project(self):
        """Gets the project of this ResponseExperimentListResponse.  # noqa: E501


        :return: The project of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: ResponseProject
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this ResponseExperimentListResponse.


        :param project: The project of this ResponseExperimentListResponse.  # noqa: E501
        :type project: ResponseProject
        """
        if self.local_vars_configuration.client_side_validation and project is None:  # noqa: E501
            raise ValueError("Invalid value for `project`, must not be `None`")  # noqa: E501

        self._project = project

    @property
    def show_plots(self):
        """Gets the show_plots of this ResponseExperimentListResponse.  # noqa: E501


        :return: The show_plots of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: bool
        """
        return self._show_plots

    @show_plots.setter
    def show_plots(self, show_plots):
        """Sets the show_plots of this ResponseExperimentListResponse.


        :param show_plots: The show_plots of this ResponseExperimentListResponse.  # noqa: E501
        :type show_plots: bool
        """
        if self.local_vars_configuration.client_side_validation and show_plots is None:  # noqa: E501
            raise ValueError("Invalid value for `show_plots`, must not be `None`")  # noqa: E501

        self._show_plots = show_plots

    @property
    def status(self):
        """Gets the status of this ResponseExperimentListResponse.  # noqa: E501


        :return: The status of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ResponseExperimentListResponse.


        :param status: The status of this ResponseExperimentListResponse.  # noqa: E501
        :type status: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def status_last_updated(self):
        """Gets the status_last_updated of this ResponseExperimentListResponse.  # noqa: E501


        :return: The status_last_updated of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._status_last_updated

    @status_last_updated.setter
    def status_last_updated(self, status_last_updated):
        """Sets the status_last_updated of this ResponseExperimentListResponse.


        :param status_last_updated: The status_last_updated of this ResponseExperimentListResponse.  # noqa: E501
        :type status_last_updated: datetime
        """
        if self.local_vars_configuration.client_side_validation and status_last_updated is None:  # noqa: E501
            raise ValueError("Invalid value for `status_last_updated`, must not be `None`")  # noqa: E501

        self._status_last_updated = status_last_updated

    @property
    def status_reason(self):
        """Gets the status_reason of this ResponseExperimentListResponse.  # noqa: E501


        :return: The status_reason of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: str
        """
        return self._status_reason

    @status_reason.setter
    def status_reason(self, status_reason):
        """Sets the status_reason of this ResponseExperimentListResponse.


        :param status_reason: The status_reason of this ResponseExperimentListResponse.  # noqa: E501
        :type status_reason: str
        """
        if self.local_vars_configuration.client_side_validation and status_reason is None:  # noqa: E501
            raise ValueError("Invalid value for `status_reason`, must not be `None`")  # noqa: E501

        self._status_reason = status_reason

    @property
    def sweep(self):
        """Gets the sweep of this ResponseExperimentListResponse.  # noqa: E501


        :return: The sweep of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: ResponseSimpleSweep
        """
        return self._sweep

    @sweep.setter
    def sweep(self, sweep):
        """Sets the sweep of this ResponseExperimentListResponse.


        :param sweep: The sweep of this ResponseExperimentListResponse.  # noqa: E501
        :type sweep: ResponseSimpleSweep
        """

        self._sweep = sweep

    @property
    def tags(self):
        """Gets the tags of this ResponseExperimentListResponse.  # noqa: E501


        :return: The tags of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: list[ResponseTagResponse]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ResponseExperimentListResponse.


        :param tags: The tags of this ResponseExperimentListResponse.  # noqa: E501
        :type tags: list[ResponseTagResponse]
        """
        if self.local_vars_configuration.client_side_validation and tags is None:  # noqa: E501
            raise ValueError("Invalid value for `tags`, must not be `None`")  # noqa: E501

        self._tags = tags

    @property
    def updated_dt(self):
        """Gets the updated_dt of this ResponseExperimentListResponse.  # noqa: E501


        :return: The updated_dt of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this ResponseExperimentListResponse.


        :param updated_dt: The updated_dt of this ResponseExperimentListResponse.  # noqa: E501
        :type updated_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    @property
    def workload_status(self):
        """Gets the workload_status of this ResponseExperimentListResponse.  # noqa: E501


        :return: The workload_status of this ResponseExperimentListResponse.  # noqa: E501
        :rtype: str
        """
        return self._workload_status

    @workload_status.setter
    def workload_status(self, workload_status):
        """Sets the workload_status of this ResponseExperimentListResponse.


        :param workload_status: The workload_status of this ResponseExperimentListResponse.  # noqa: E501
        :type workload_status: str
        """

        self._workload_status = workload_status

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseExperimentListResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseExperimentListResponse):
            return True

        return self.to_dict() != other.to_dict()
